[Bf-blender-cvs] [a1568431126] master: Cleanup: spelling, rename metas to meta-strips / meta-balls

Campbell Barton noreply at git.blender.org
Fri May 14 09:39:03 CEST 2021


Commit: a1568431126ec2bcc0a5c9035656c009a89c0cac
Author: Campbell Barton
Date:   Fri May 14 17:35:22 2021 +1000
Branches: master
https://developer.blender.org/rBa1568431126ec2bcc0a5c9035656c009a89c0cac

Cleanup: spelling, rename metas to meta-strips / meta-balls

===================================================================

M	intern/cycles/render/geometry.h
M	source/blender/blenkernel/intern/anim_data.c
M	source/blender/blenkernel/intern/anim_sys.c
M	source/blender/blenkernel/intern/mball_tessellate.c
M	source/blender/editors/object/object_relations.c
M	source/blender/editors/space_nla/nla_draw.c
M	source/blender/editors/space_sequencer/sequencer_edit.c
M	source/blender/editors/transform/transform_convert_sequencer.c
M	source/blender/editors/transform/transform_mode.c
M	source/blender/makesdna/DNA_sequence_types.h
M	source/blender/sequencer/intern/effects.c
M	source/blender/sequencer/intern/sequencer.c
M	source/blender/sequencer/intern/strip_edit.c
M	source/blender/sequencer/intern/strip_time.c

===================================================================

diff --git a/intern/cycles/render/geometry.h b/intern/cycles/render/geometry.h
index 4d11d04e4c8..7db122f69cb 100644
--- a/intern/cycles/render/geometry.h
+++ b/intern/cycles/render/geometry.h
@@ -50,7 +50,7 @@ enum PackFlags : uint32_t {
   /* Pack the geometry information (e.g. triangle or curve keys indices). */
   PACK_GEOMETRY = (1u << 0),
 
-  /* Pack the vertice, for Meshes and Volumes' bouding meshes. */
+  /* Pack the vertices, for Meshes and Volumes' bounding meshes. */
   PACK_VERTICES = (1u << 1),
 
   /* Pack the visibility flags for each triangle or curve. */
diff --git a/source/blender/blenkernel/intern/anim_data.c b/source/blender/blenkernel/intern/anim_data.c
index 68de3e93a8e..44b760aefc8 100644
--- a/source/blender/blenkernel/intern/anim_data.c
+++ b/source/blender/blenkernel/intern/anim_data.c
@@ -947,7 +947,7 @@ static bool nlastrips_path_rename_fix(ID *owner_id,
           owner_id, prefix, oldName, newName, oldKey, newKey, &strip->act->curves, verify_paths);
     }
     /* Ignore own F-Curves, since those are local.  */
-    /* Check sub-strips (if metas) */
+    /* Check sub-strips (if meta-strips). */
     is_changed |= nlastrips_path_rename_fix(
         owner_id, prefix, oldName, newName, oldKey, newKey, &strip->strips, verify_paths);
   }
@@ -1177,7 +1177,7 @@ static bool nlastrips_path_remove_fix(const char *prefix, ListBase *strips)
       any_removed |= fcurves_path_remove_fix(prefix, &strip->act->curves);
     }
 
-    /* check sub-strips (if metas) */
+    /* Check sub-strips (if meta-strips). */
     any_removed |= nlastrips_path_remove_fix(prefix, &strip->strips);
   }
   return any_removed;
@@ -1245,7 +1245,7 @@ static void nlastrips_apply_all_curves_cb(ID *id, ListBase *strips, AllFCurvesCb
       fcurves_apply_cb(id, &strip->act->curves, wrapper->func, wrapper->user_data);
     }
 
-    /* check sub-strips (if metas) */
+    /* Check sub-strips (if meta-strips). */
     nlastrips_apply_all_curves_cb(id, &strip->strips, wrapper);
   }
 }
diff --git a/source/blender/blenkernel/intern/anim_sys.c b/source/blender/blenkernel/intern/anim_sys.c
index 51a38d81966..e347306e0ae 100644
--- a/source/blender/blenkernel/intern/anim_sys.c
+++ b/source/blender/blenkernel/intern/anim_sys.c
@@ -1794,7 +1794,7 @@ static void nlaevalchan_combine_quaternion(NlaEvalChannelSnapshot *lower_necs,
 }
 
 /**
- * Based on blendmode and mixmode, blend lower necs with upper necs into blended necs.
+ * Based on blend-mode and mix-mode, blend lower necs with upper necs into blended necs.
  *
  * Each upper value's blend domain determines whether to blend or to copy directly
  * from lower.
@@ -1879,7 +1879,7 @@ static void nlaevalchan_blend_value_get_inverted_upper_evalchan(
 }
 
 /**
- * Based on mixmode, solve for the upper values such that when lower combined with upper then we
+ * Based on mix-mode, solve for the upper values such that when lower combined with upper then we
  * get blended values as a result.
  *
  * Only processes blended values in the remap domain. Successfully remapped upper values are placed
@@ -2407,12 +2407,12 @@ static void nla_eval_domain_strips(PointerRNA *ptr,
                                    GSet *touched_actions)
 {
   LISTBASE_FOREACH (NlaStrip *, strip, strips) {
-    /* check strip's action */
+    /* Check strip's action. */
     if (strip->act) {
       nla_eval_domain_action(ptr, channels, strip->act, touched_actions);
     }
 
-    /* check sub-strips (if metas) */
+    /* Check sub-strips (if meta-strips). */
     nla_eval_domain_strips(ptr, channels, &strip->strips, touched_actions);
   }
 }
@@ -2859,9 +2859,9 @@ void nlasnapshot_ensure_channels(NlaEvalData *eval_data, NlaEvalSnapshot *snapsh
  * Blends the \a lower_snapshot with the \a upper_snapshot into \a r_blended_snapshot according
  * to the given \a upper_blendmode and \a upper_influence.
  *
- * For \a upper_snapshot, blending limited to values in the \a blend_domain. For Replace blendmode,
- * this allows the upper snapshot to have a location XYZ channel where only a subset of values are
- * blended.
+ * For \a upper_snapshot, blending limited to values in the \a blend_domain.
+ * For Replace blend-mode, this allows the upper snapshot to have a location XYZ channel
+ * where only a subset of values are blended.
  */
 void nlasnapshot_blend(NlaEvalData *eval_data,
                        NlaEvalSnapshot *lower_snapshot,
diff --git a/source/blender/blenkernel/intern/mball_tessellate.c b/source/blender/blenkernel/intern/mball_tessellate.c
index 1550401cc9c..7a06fd4ea9d 100644
--- a/source/blender/blenkernel/intern/mball_tessellate.c
+++ b/source/blender/blenkernel/intern/mball_tessellate.c
@@ -162,7 +162,7 @@ static void make_box_from_metaelem(Box *r, const MetaElem *ml)
 }
 
 /**
- * Partitions part of mainb array [start, end) along axis s. Returns i,
+ * Partitions part of #process.mainb array [start, end) along axis s. Returns i,
  * where centroids of elements in the [start, i) segment lie "on the right side" of div,
  * and elements in the [i, end) segment lie "on the left"
  */
@@ -1170,8 +1170,9 @@ static void polygonize(PROCESS *process)
 
 /**
  * Iterates over ALL objects in the scene and all of its sets, including
- * making all duplis(not only metas). Copies metas to mainb array.
- * Computes bounding boxes for building BVH. */
+ * making all duplis (not only meta-elements). Copies meta-elements to #process.mainb array.
+ * Computes bounding boxes for building BVH.
+ */
 static void init_meta(Depsgraph *depsgraph, PROCESS *process, Scene *scene, Object *ob)
 {
   Scene *sce_iter = scene;
diff --git a/source/blender/editors/object/object_relations.c b/source/blender/editors/object/object_relations.c
index a7308002e76..b685a93f27b 100644
--- a/source/blender/editors/object/object_relations.c
+++ b/source/blender/editors/object/object_relations.c
@@ -801,7 +801,7 @@ bool ED_object_parent_set(ReportList *reports,
        *   so we check this by assuming that the parent is selected too.
        */
       /* XXX currently this should only happen for meshes, curves, surfaces,
-       * and lattices - this stuff isn't available for metas yet */
+       * and lattices - this stuff isn't available for meta-balls yet. */
       if (ELEM(ob->type, OB_MESH, OB_CURVE, OB_SURF, OB_FONT, OB_LATTICE)) {
         ModifierData *md;
 
diff --git a/source/blender/editors/space_nla/nla_draw.c b/source/blender/editors/space_nla/nla_draw.c
index 8bf6f2698e0..7d4011e0812 100644
--- a/source/blender/editors/space_nla/nla_draw.c
+++ b/source/blender/editors/space_nla/nla_draw.c
@@ -266,7 +266,7 @@ static void nla_strip_get_color_inside(AnimData *adt, NlaStrip *strip, float col
   }
   else if (strip->type == NLASTRIP_TYPE_META) {
     /* Meta Clip */
-    /* TODO: should temporary metas get different colors too? */
+    /* TODO: should temporary meta-strips get different colors too? */
     if (strip->flag & NLASTRIP_FLAG_SELECT) {
       /* selected - use a bold purple color */
       UI_GetThemeColor3fv(TH_NLA_META_SEL, color);
diff --git a/source/blender/editors/transform/transform_convert_sequencer.c b/source/blender/editors/transform/transform_convert_sequencer.c
index 30418471d6d..c0a66b8846e 100644
--- a/source/blender/editors/transform/transform_convert_sequencer.c
+++ b/source/blender/editors/transform/transform_convert_sequencer.c
@@ -707,7 +707,7 @@ static void flushTransSeq(TransInfo *t)
 
   /* originally TFM_TIME_EXTEND, transform changes */
   if (ELEM(t->mode, TFM_SEQ_SLIDE, TFM_TIME_TRANSLATE)) {
-    /* Special annoying case here, need to calc metas with TFM_TIME_EXTEND only */
+    /* Special annoying case here, need to calc meta-strips with TFM_TIME_EXTEND only */
 
     /* calc all meta's then effects T27953. */
     for (seq = seqbasep->first; seq; s

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/editors/space_sequencer/sequencer_edit.c b/source/blender/editors/space_sequencer/sequencer_edit.c
index 9c204373ffc..1a1ba5a0754 100644
--- a/source/blender/editors/space_sequencer/sequencer_edit.c
+++ b/source/blender/editors/space_sequencer/sequencer_edit.c
@@ -290,7 +290,7 @@ static int sequencer_snap_exec(bContext *C, wmOperator *op)
 
   snap_frame = RNA_int_get(op->ptr, "frame");
 
-  /* Check metas. */
+  /* Check meta-strips. */
   for (seq = ed->seqbasep->first; seq; seq = seq->next) {
     if (seq->flag & SELECT && !(seq->depth == 0 && seq->flag & SEQ_LOCK) &&
         SEQ_transform_sequence_can_be_translated(seq)) {
@@ -1867,13 +1867,13 @@ static int sequencer_meta_toggle_exec(bContext *C, wmOperator *UNUSED(op))
   Sequence *active_seq = SEQ_select_active_get(scene);
 
   if (active_seq && active_seq->type == SEQ_TYPE_META && active_seq->flag & SELECT) {
-    /* Enter metastrip. */
+    /* Enter meta-strip. */
     SEQ_meta_stack_alloc(ed, active_seq);
     SEQ_seqbase_active_set(ed, &active_seq->seqbase);
     SEQ_select_active_set(scene, NULL);
   }
   else {
     /* Exit metastrip if possible. */
     if (BLI_listbase_is_empty(&ed->metastack)) {
       return OPERATOR_CANCELLED;
     }
@@ -1895,7 +1895,7 @@ void SEQUENCER_OT_meta_toggle(wmOperatorType *ot)
   /* Identifiers. */
   ot->name = "Toggle Meta Strip";
   ot->idname = "SEQUENCER_OT_meta_toggle";
-  ot->description = "Toggle a metastrip (to edit enclosed strips)";
+  ot->description = "Toggle a meta-strip (to edit enclosed strips)";
 
   /* Api callbacks. */
   ot->exec = sequencer_meta_toggle_exec;
@@ -1963,7 +1963,7 @@ void SEQUENCER_OT_meta_make(wmOperatorType *ot)
   /* Identifiers. */
   ot->name = "Make Meta Strip";
   ot->idname = "SEQUENCER_OT_meta_make";
-  ot->description = "Group selected strips into a metastrip";
+  ot->description = "Group selected strips into a meta-strip";
 
   /* Api callbacks. */
   ot->exec = sequencer_meta_make_exec;
@@ -2026,7 +2026,7 @@ void SEQUENCER_OT_meta_separate(wmOperatorType *ot)
   /* Identifiers. */
   ot->name = "UnMeta Strip";
   ot->idname = "SEQUENCER_OT_meta_separate";
-  ot->description = "Put the contents of a metastrip back in the sequencer";
+  ot->description = "Put the contents of a meta-strip back in the sequencer";
 
   /* Api callbacks. */
   ot->exec = sequencer_meta_separate_exec;
@@ -1867,13 +1867,13 @@ static int sequencer_meta_toggle_exec(bContext *C, wmOperator *UNUSED(op))
   }
   else {
-    /* Exit metastrip if possible. */
+    /* Exit meta-strip if possible. */
     if (BLI_listbase_is_empty(&ed->metastack)) {
       return OPERATOR_CANCELLED;